@@ -4,11 +4,13 @@ import { compare } from 'bcrypt';
 import config from 'config';
 import { promisify } from 'util';
 import crypto from 'crypto';
+import { version } from '../../package.json';
 
 import { SERVER_TYPES, VISIBILITY_STATUSES } from '@tamanu/constants';
 import { BadAuthenticationError, ForbiddenError } from '@tamanu/shared/errors';
 import { log } from '@tamanu/shared/services/logging';
 import { getPermissionsForRoles } from '@tamanu/shared/permissions/rolesToPermissions';
+import { createSessionIdentifier } from '@tamanu/shared/audit/createSessionIdentifier';
 import { selectFacilityIds } from '@tamanu/utils/selectFacilityIds';
 
 import { CentralServerConnection } from '../sync';
@@ -247,19 +249,44 @@ async function getUser(models, userId) {
 }
 
 export const authMiddleware = async (req, res, next) => {
-  const { models } = req;
+  const { models, settings } = req;
   try {
     const token = getTokenFromHeaders(req);
+    const sessionId = createSessionIdentifier(token);
     const { userId, facilityId } = await decodeToken(token);
     const user = await getUser(models, userId);
     req.user = user; // eslint-disable-line require-atomic-updates
     req.facilityId = facilityId; // eslint-disable-line require-atomic-updates
+    req.sessionId = sessionId; // eslint-disable-line require-atomic-updates
     req.getLocalisation = async () =>
       req.models.UserLocalisationCache.getLocalisation({
         where: { userId: req.user.id },
         order: [['createdAt', 'DESC']],
       });
 
+    const auditSettings = await settings?.[req.facilityId]?.get('audit');
+
+    // Auditing middleware
+    // eslint-disable-next-line require-atomic-updates
+    req.audit = {
+      access: async ({ recordId, params, model }) => {
+        if (!auditSettings?.accesses.enabled) return;
+        return req.models.AccessLog.create({
+          userId,
+          recordId,
+          recordType: model.name,
+          sessionId,
+          isMobile: false,
+          frontEndContext: params,
+          backEndContext: { endpoint: req.originalUrl },
+          loggedAt: new Date(),
+          facilityId: req.facilityId,
+          deviceId: req.deviceId || 'unknown-device',
+          version,
+        });
+      },
+    };
+
     const spanAttributes = {};
     if (req.user) {
       spanAttributes['enduser.id'] = req.user.id;
